@@ -1,9 +1,8 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-#ifndef _GNM_EXPR_NAME_H_
-# define _GNM_EXPR_NAME_H_
+#ifndef GNM_EXPR_NAME_H_
+#define GNM_EXPR_NAME_H_
 
-#include "gnumeric.h"
-#include "position.h"
+#include <gnumeric.h>
+#include <position.h>
 #include <goffice/goffice.h>
 
 G_BEGIN_DECLS
@@ -14,7 +13,6 @@ struct _GnmNamedExpr {
 	GnmParsePos    pos;
 	GHashTable *dependents;
 	GnmExprTop const *texpr;
-	gboolean    is_placeholder;
 	gboolean    is_hidden;
 	gboolean    is_permanent;
 	gboolean    is_editable;
@@ -23,6 +21,7 @@ struct _GnmNamedExpr {
 
 gboolean expr_name_validate (const char *name);
 
+GType         gnm_named_expr_get_type (void);
 GnmNamedExpr *expr_name_new    (char const *name);
 GnmNamedExpr *expr_name_lookup (GnmParsePos const *pos, char const *name);
 GnmNamedExpr *expr_name_add    (GnmParsePos const *pp, char const *name,
@@ -33,25 +32,25 @@ void expr_name_perm_add        (Sheet *sheet,
 				char const *name,
 				GnmExprTop const *texpr,
 				gboolean is_editable);
-void	 expr_name_ref	      (GnmNamedExpr *nexpr);
+GnmNamedExpr *expr_name_ref   (GnmNamedExpr *nexpr);
 void	 expr_name_unref      (GnmNamedExpr *nexpr);
 void     expr_name_remove     (GnmNamedExpr *nexpr);
-GnmValue*expr_name_eval       (GnmNamedExpr const *ne, GnmEvalPos const *ep,
+GnmValue*expr_name_eval       (GnmNamedExpr const *nexpr,
+			       GnmEvalPos const *pos,
 			       GnmExprEvalFlags flags);
 
 const char *expr_name_name    (GnmNamedExpr const *nexpr);
 gboolean expr_name_set_name   (GnmNamedExpr *nexpr, const char *new_name);
 
 gboolean expr_name_is_placeholder (GnmNamedExpr const *ne);
-void expr_name_set_is_placeholder (GnmNamedExpr *ne, gboolean is_placeholder);
 
-char    *expr_name_as_string  (GnmNamedExpr const *ne, GnmParsePos const *pp,
+char    *expr_name_as_string  (GnmNamedExpr const *nexpr, GnmParsePos const *pp,
 			       GnmConventions const *fmt);
-char    *expr_name_set_pos    (GnmNamedExpr *ne, GnmParsePos const *pp);
-void	 expr_name_set_expr   (GnmNamedExpr *ne, GnmExprTop const *texpr);
-void	 expr_name_add_dep    (GnmNamedExpr *ne, GnmDependent *dep);
-void	 expr_name_remove_dep (GnmNamedExpr *ne, GnmDependent *dep);
-gboolean expr_name_is_active  (GnmNamedExpr const *ne);
+char    *expr_name_set_pos    (GnmNamedExpr *nexpr, GnmParsePos const *pp);
+void	 expr_name_set_expr   (GnmNamedExpr *nexpr, GnmExprTop const *texpr);
+void	 expr_name_add_dep    (GnmNamedExpr *nexpr, GnmDependent *dep);
+void	 expr_name_remove_dep (GnmNamedExpr *nexpr, GnmDependent *dep);
+gboolean expr_name_is_active  (GnmNamedExpr const *nexpr);
 void	 expr_name_downgrade_to_placeholder (GnmNamedExpr *nexpr);
 gboolean expr_name_in_use     (GnmNamedExpr *nexpr);
 
@@ -60,20 +59,13 @@ gboolean expr_name_check_for_loop (char const *name, GnmExprTop const *texpr);
 
 char const *sheet_names_check	      (Sheet const *sheet, GnmRange const *r);
 
-GOUndo *expr_name_set_expr_undo_new (GnmNamedExpr *ne);
+GOUndo *expr_name_set_expr_undo_new (GnmNamedExpr *nexpr);
 
 /******************************************************************************/
 
-struct _GnmNamedExprCollection {
-	/* all the defined names */
-	GHashTable *names;
-
-	/* placeholders for references to undefined names */
-	GHashTable *placeholders;
-};
-
+GType gnm_named_expr_collection_get_type (void);
 GnmNamedExprCollection *gnm_named_expr_collection_new (void);
-void gnm_named_expr_collection_free (GnmNamedExprCollection *names);
+void gnm_named_expr_collection_unref (GnmNamedExprCollection *names);
 void gnm_named_expr_collection_unlink (GnmNamedExprCollection *names);
 void gnm_named_expr_collection_relink (GnmNamedExprCollection *names);
 void gnm_named_expr_collection_foreach (GnmNamedExprCollection *names,
@@ -83,6 +75,11 @@ GSList  *gnm_named_expr_collection_list (GnmNamedExprCollection const *scope);
 
 GnmNamedExpr *gnm_named_expr_collection_lookup (GnmNamedExprCollection const *scope,
 						char const *name);
+void gnm_named_expr_collection_dump (GnmNamedExprCollection *names,
+				     const char *id);
+gboolean gnm_named_expr_collection_sanity_check (GnmNamedExprCollection *names,
+						 const char *id);
+
 G_END_DECLS
 
-#endif /* _GNM_EXPR_NAME_H_ */
+#endif /* GNM_EXPR_NAME_H_ */
