@@ -1,6 +1,5 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-#ifndef _GNM_XML_IO_VERSION_H_
-# define _GNM_XML_IO_VERSION_H_
+#ifndef GNM_XML_IO_VERSION_H_
+#define GNM_XML_IO_VERSION_H_
 
 G_BEGIN_DECLS
 
@@ -20,11 +19,12 @@ typedef enum
 	GNM_XML_V11,	/* >= 1.7.0 jump to sax exporter */
 	GNM_XML_V12,	/* >= 1.7.3 Fix swapping of Value and ValueType in sax exporter */
 	GNM_XML_V13,	/* >= 1.7.7 Deprecate ObjectAnchorType */
+	GNM_XML_V14,	/* >= 1.12.21 Various */
 
 	/* NOTE : Keep this up to date (and in sync with the schema) */
-	GNM_XML_LATEST = GNM_XML_V13
+	GNM_XML_LATEST = GNM_XML_V14
 } GnumericXMLVersion;
 
 G_END_DECLS
 
-#endif /* _GNM_XML_IO_VERSION_H_ */
+#endif /* GNM_XML_IO_VERSION_H_ */
